BackendMsg class final
Opaque type representing a message produced by a C++ service.
The actual memory layout is defined on the C++ side. Dart only ever manipulates Pointer<BackendMsg> values — it never dereferences this type directly. Use the extra functions exposed by your Service subclass to read fields from the pointer.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited